@@ -7,18 +7,23 @@ from lxml import etree
 
 
 # will return a list of nodes specified by an attribute key and an attribute value from a parent node
-def get_child_nodes(node_parent, node_tag, node_att_name=None, node_att_val=None, namespace_map=None, filter_comment_nodes=True):
+def get_child_nodes(node_parent, node_tag, node_att_name=None, node_att_val=None, namespace_map=None,
+                    filter_comment_nodes=True):
     selector = node_tag
-    return find_all_nodes(node_parent, node_tag, node_att_name, node_att_val, recursive=False, namespace_map=namespace_map, filter_comment_nodes=filter_comment_nodes)
+    return find_all_nodes(node_parent, node_tag, node_att_name, node_att_val, recursive=False,
+                          namespace_map=namespace_map, filter_comment_nodes=filter_comment_nodes)
 
 
 # will search in all of the direct children of the root
-def get_root_direct_child_nodes(xml_file, node_tag, node_att_name=None, node_att_val=None, namespace_map=None, filter_comment_nodes=True):
-    return get_child_nodes(get_root_node(xml_file), node_tag, node_att_name, node_att_val, namespace_map, filter_comment_nodes)
+def get_root_direct_child_nodes(xml_file, node_tag, node_att_name=None, node_att_val=None, namespace_map=None,
+                                filter_comment_nodes=True):
+    return get_child_nodes(get_root_node(xml_file), node_tag, node_att_name, node_att_val, namespace_map,
+                           filter_comment_nodes)
 
 
 # will return a list of nodes which doesn't have a specific attribute
-def get_nodes_from_xml_without_att(xml_file, node_tag, node_att_name=None, namespace_map=None, filter_comment_nodes=True):
+def get_nodes_from_xml_without_att(xml_file, node_tag, node_att_name=None, namespace_map=None,
+                                   filter_comment_nodes=True):
     root = xml_file.getroot()
     relevant_nodes = []
     node_att_name = _sanitize_att_name(node_att_name, namespace_map)
@@ -226,7 +231,8 @@ def set_node_atts(node, atts_dict, namespace_map=None):
 
 
 # will search for a node
-def find_all_nodes(parent_node, node_tag, node_att_name=None, node_att_val=None, recursive=True, namespace_map=None, filter_comment_nodes=True):
+def find_all_nodes(parent_node, node_tag, node_att_name=None, node_att_val=None, recursive=True, namespace_map=None,
+                   filter_comment_nodes=True):
     selector = node_tag
     if node_att_name is not None:
         node_att_name = _sanitize_att_name(node_att_name, namespace_map)
@@ -243,6 +249,14 @@ def find_all_nodes(parent_node, node_tag, node_att_name=None, node_att_val=None,
     return nodes
 
 
+def remove_node(node):
+    node.getparent().remove(node)
+
+
+def remove_attrib_from_node(node, att):
+    node.attrib.pop(att, None)
+
+
 # will parse the namespace, as required, in the att_name
 def _sanitize_att_name(att_name, namespace_map):
     if namespace_map is not None:
